@@ -33,12 +33,13 @@ extern "C" {
     struct PySideQFlagsType
     {
         PyHeapTypeObject super;
+        SbkConverter** converterPtr;
         SbkConverter* converter;
     };
 
     #define PYSIDE_QFLAGS(X) reinterpret_cast<PySideQFlagsObject*>(X)
 
-    PyObject* PySideQFlagsNew(PyTypeObject *type, PyObject *args, PyObject *kwds)
+    PyObject* PySideQFlagsNew(PyTypeObject* type, PyObject* args, PyObject* kwds)
     {
         long val = 0;
         if (PyTuple_GET_SIZE(args)) {
@@ -60,13 +61,11 @@ extern "C" {
 
     static long getNumberValue(PyObject* v)
     {
-        PyObject* number = PyNumber_Long(v);
-        long result = PyLong_AsLong(number);
-        Py_XDECREF(number);
-        return result;
+        Shiboken::AutoDecRef number(PyNumber_Long(v));
+        return PyLong_AsLong(number);
     }
 
-    PyObject* PySideQFlagsRichCompare(PyObject *self, PyObject *other, int op)
+    PyObject* PySideQFlagsRichCompare(PyObject* self, PyObject* other, int op)
     {
         int result = 0;
         if (!PyNumber_Check(other)) {
@@ -127,6 +126,9 @@ namespace QFlags
         type->tp_as_number = numberMethods;
         type->tp_richcompare = &PySideQFlagsRichCompare;
 
+        PySideQFlagsType* flagsType = reinterpret_cast<PySideQFlagsType*>(type);
+        flagsType->converterPtr = &flagsType->converter;
+
         if (PyType_Ready(type) < 0)
             return 0;
 
@@ -146,4 +148,3 @@ namespace QFlags
     }
 }
 }
-
